==> vueform-1.5.5.tgz: package/src/composables/elements/useDefault.js <==
import _ from 'lodash'
import { computed, toRefs, inject } from 'vue'
import localize from '../../utils/localize'

const base = function(props, context, dependencies)
{
  const {
    default: default_,
    name,
  } = toRefs(props)
  
  // ============ DEPENDENCIES =============
  
  const nullValue = dependencies.nullValue
  const form$ = dependencies.form$
  const parent = dependencies.parent
  
  // ============== COMPUTED ===============
  
  /**
   * The default value of the element.
   *
   * @type {any}
   * @private
   */
  const defaultValue = computed(() => {
    let parentDefaultValue
    
    if (parent && parent.value && !parent.value.mounted) {
      parentDefaultValue = parent.value.defaultValue[name.value]
    } else if (!form$.value.mounted && form$.value.options.default[name.value]) {
      parentDefaultValue = form$.value.options.default[name.value]
    }
    
    if (parentDefaultValue !== undefined) {
      return parentDefaultValue instanceof File
        ? new File([parentDefaultValue], parentDefaultValue.name, parentDefaultValue)
        : _.cloneDeep(parentDefaultValue)
    }
    
    if (default_.value !== undefined) {
      return default_.value instanceof File
        ? new File([default_.value], default_.value.name, default_.value)
        : _.cloneDeep(default_.value)
    }
    
    return _.cloneDeep(nullValue.value)
  })
  
  return {
    defaultValue,
  }
}

const text = function(props, context, dependencies)
{
  const {
    default: default_,
    name,
  } = toRefs(props)
  
  // ============ DEPENDENCIES =============
  
  const nullValue = dependencies.nullValue
  const form$ = dependencies.form$
  const parent = dependencies.parent
  
  // =============== INJECT ===============
  
  const config$ = inject('config$')
  
  // ============== COMPUTED ===============
  
  /**
   * The default value of the element.
   *
   * @type {any}
   * @private
   */
  const defaultValue = computed(() => {
    let parentDefaultValue
    
    if (parent && parent.value && !parent.value.mounted) {
      parentDefaultValue = parent.value.defaultValue[name.value]
    } else if (!form$.value.mounted && form$.value.options.default[name.value]) {
      parentDefaultValue = form$.value.options.default[name.value]
    }
    
    if (parentDefaultValue !== undefined) {
      return parentDefaultValue instanceof File
        ? new File([parentDefaultValue], parentDefaultValue.name, parentDefaultValue)
        : (_.isPlainObject(parentDefaultValue)
          ? localize(_.cloneDeep(parentDefaultValue), config$.value, form$.value)
          : _.cloneDeep(parentDefaultValue))
    }
    
    /* istanbul ignore else */
    if (default_.value !== undefined) {
      /* istanbul ignore next: text can not have File as default */
      return default_.value instanceof File
        ? new File([default_.value], default_.value.name, default_.value)
        : _.isPlainObject(default_.value)
          ? localize(_.cloneDeep(default_.value), config$.value, form$.value)
          : _.cloneDeep(default_.value)
    }
    
    /* istanbul ignore next: text will never fall into this case, because `default_.value` is never undefined but null */
    return _.cloneDeep(nullValue.value)
  })
  
  return {
    defaultValue,
  }
}

const object = function(props, context, dependencies)
{
  const {
    default: default_,
    name,
  } = toRefs(props)
  
  // ============ DEPENDENCIES =============
  
  const nullValue = dependencies.nullValue
  const form$ = dependencies.form$
  const parent = dependencies.parent
  
  // ============== COMPUTED ===============
  
  const defaultValue = computed(() => {
    let parentDefaultValue
    
    if (parent && parent.value && !parent.value.mounted) {
      parentDefaultValue = parent.value.defaultValue[name.value]
    } else if (!form$.value.mounted && form$.value.options.default[name.value]) {
      parentDefaultValue = form$.value.options.default[name.value]
    }
    
    if (parentDefaultValue !== undefined) {
      return _.cloneDeep(_.merge({}, default_.value || /* istanbul ignore next: `default_.value` will never be undefined, because it is a hardwired `{}` */ nullValue.value, parentDefaultValue))
    }
    
    if (Object.keys(default_.value).length > 0) {
      return _.cloneDeep(default_.value)
    }
    
    return _.cloneDeep(nullValue.value)
  })
  
  return {
    defaultValue,
  }
}

const group = function(props, context, dependencies)
{
  const {
    default: default_,
  } = toRefs(props)
  
  // ============ DEPENDENCIES =============
  
  const form$ = dependencies.form$
  const parent = dependencies.parent
  
  // ============== COMPUTED ===============
  
  const defaultValue = computed(() => {
    let parentDefaultValue = {}
    
    if (parent && parent.value && !parent.value.mounted) {
      parentDefaultValue = parent.value.defaultValue
    } else if (!form$.value.mounted && form$.value.options.default) { //@todo:adam
      parentDefaultValue = form$.value.options.default
    }
    
    return _.cloneDeep(_.merge({}, default_.value, parentDefaultValue))
  })
  
  return {
    defaultValue,
  }
}

const multilingual = function(props, context, dependencies)
{
  const {
    default: default_,
    name,
  } = toRefs(props)
  
  // ============ DEPENDENCIES =============
  
  const nullValue = dependencies.nullValue
  const form$ = dependencies.form$
  const parent = dependencies.parent
  
  // ============== COMPUTED ===============
  
  const defaultValue = computed(() => {
    let parentDefaultValue
    
    if (parent && parent.value && !parent.value.mounted) {
      parentDefaultValue = parent.value.defaultValue[name.value]
    } else if (!form$.value.mounted && form$.value.options.default[name.value]) {
      parentDefaultValue = form$.value.options.default[name.value]
    }
    
    if (parentDefaultValue !== undefined) {
      return _.cloneDeep(Object.assign({}, _.clone(nullValue.value), parentDefaultValue))
    }
    
    if (default_.value === undefined) {
      return _.clone(nullValue.value)
    }
    
    let def = _.clone(default_.value)
    
    if (!_.isPlainObject(def)) {
      let tempDefault = {}
      
      _.each(nullValue.value, (v, language) => {
        tempDefault[language] = def
      })
      
      def = tempDefault
    }
    
    return Object.assign({}, _.clone(nullValue.value), def)
  })
  
  return {
    defaultValue,
  }
}

export {
  object,
  group,
  multilingual,
  text,
}

export default base

==> vueform-1.5.7.tgz: package/src/composables/elements/useDefault.js <==
import each from 'lodash-es/each'
import cloneDeep from 'lodash-es/cloneDeep'
import isPlainObject from 'lodash-es/isPlainObject'
import merge from 'lodash-es/merge'
import clone from 'lodash-es/clone'
import { computed, toRefs, inject } from 'vue'
import localize from '../../utils/localize'

const base = function(props, context, dependencies)
{
  const {
    default: default_,
    name,
  } = toRefs(props)
  
  // ============ DEPENDENCIES =============
  
  const nullValue = dependencies.nullValue
  const form$ = dependencies.form$
  const parent = dependencies.parent
  
  // ============== COMPUTED ===============
  
  /**
   * The default value of the element.
   *
   * @type {any}
   * @private
   */
  const defaultValue = computed(() => {
    let parentDefaultValue
    
    if (parent && parent.value && !parent.value.mounted) {
      parentDefaultValue = parent.value.defaultValue[name.value]
    } else if (!form$.value.mounted && form$.value.options.default[name.value]) {
      parentDefaultValue = form$.value.options.default[name.value]
    }
    
    if (parentDefaultValue !== undefined) {
      return parentDefaultValue instanceof File
        ? new File([parentDefaultValue], parentDefaultValue.name, parentDefaultValue)
        : cloneDeep(parentDefaultValue)
    }
    
    if (default_.value !== undefined) {
      return default_.value instanceof File
        ? new File([default_.value], default_.value.name, default_.value)
        : cloneDeep(default_.value)
    }
    
    return cloneDeep(nullValue.value)
  })
  
  return {
    defaultValue,
  }
}

const text = function(props, context, dependencies)
{
  const {
    default: default_,
    name,
  } = toRefs(props)
  
  // ============ DEPENDENCIES =============
  
  const nullValue = dependencies.nullValue
  const form$ = dependencies.form$
  const parent = dependencies.parent
  
  // =============== INJECT ===============
  
  const config$ = inject('config$')
  
  // ============== COMPUTED ===============
  
  /**
   * The default value of the element.
   *
   * @type {any}
   * @private
   */
  const defaultValue = computed(() => {
    let parentDefaultValue
    
    if (parent && parent.value && !parent.value.mounted) {
      parentDefaultValue = parent.value.defaultValue[name.value]
    } else if (!form$.value.mounted && form$.value.options.default[name.value]) {
      parentDefaultValue = form$.value.options.default[name.value]
    }
    
    if (parentDefaultValue !== undefined) {
      return parentDefaultValue instanceof File
        ? new File([parentDefaultValue], parentDefaultValue.name, parentDefaultValue)
        : (isPlainObject(parentDefaultValue)
          ? localize(cloneDeep(parentDefaultValue), config$.value, form$.value)
          : cloneDeep(parentDefaultValue))
    }
    
    /* istanbul ignore else */
    if (default_.value !== undefined) {
      /* istanbul ignore next: text can not have File as default */
      return default_.value instanceof File
        ? new File([default_.value], default_.value.name, default_.value)
        : isPlainObject(default_.value)
          ? localize(cloneDeep(default_.value), config$.value, form$.value)
          : cloneDeep(default_.value)
    }
    
    /* istanbul ignore next: text will never fall into this case, because `default_.value` is never undefined but null */
    return cloneDeep(nullValue.value)
  })
  
  return {
    defaultValue,
  }
}

const object = function(props, context, dependencies)
{
  const {
    default: default_,
    name,
  } = toRefs(props)
  
  // ============ DEPENDENCIES =============
  
  const nullValue = dependencies.nullValue
  const form$ = dependencies.form$
  const parent = dependencies.parent
  
  // ============== COMPUTED ===============
  
  const defaultValue = computed(() => {
    let parentDefaultValue
    
    if (parent && parent.value && !parent.value.mounted) {
      parentDefaultValue = parent.value.defaultValue[name.value]
    } else if (!form$.value.mounted && form$.value.options.default[name.value]) {
      parentDefaultValue = form$.value.options.default[name.value]
    }
    
    if (parentDefaultValue !== undefined) {
      return cloneDeep(merge({}, default_.value || /* istanbul ignore next: `default_.value` will never be undefined, because it is a hardwired `{}` */ nullValue.value, parentDefaultValue))
    }
    
    if (Object.keys(default_.value).length > 0) {
      return cloneDeep(default_.value)
    }
    
    return cloneDeep(nullValue.value)
  })
  
  return {
    defaultValue,
  }
}

const group = function(props, context, dependencies)
{
  const {
    default: default_,
  } = toRefs(props)
  
  // ============ DEPENDENCIES =============
  
  const form$ = dependencies.form$
  const parent = dependencies.parent
  
  // ============== COMPUTED ===============
  
  const defaultValue = computed(() => {
    let parentDefaultValue = {}
    
    if (parent && parent.value && !parent.value.mounted) {
      parentDefaultValue = parent.value.defaultValue
    } else if (!form$.value.mounted && form$.value.options.default) { //@todo:adam
      parentDefaultValue = form$.value.options.default
    }
    
    return cloneDeep(merge({}, default_.value, parentDefaultValue))
  })
  
  return {
    defaultValue,
  }
}

const multilingual = function(props, context, dependencies)
{
  const {
    default: default_,
    name,
  } = toRefs(props)
  
  // ============ DEPENDENCIES =============
  
  const nullValue = dependencies.nullValue
  const form$ = dependencies.form$
  const parent = dependencies.parent
  
  // ============== COMPUTED ===============
  
  const defaultValue = computed(() => {
    let parentDefaultValue
    
    if (parent && parent.value && !parent.value.mounted) {
      parentDefaultValue = parent.value.defaultValue[name.value]
    } else if (!form$.value.mounted && form$.value.options.default[name.value]) {
      parentDefaultValue = form$.value.options.default[name.value]
    }
    
    if (parentDefaultValue !== undefined) {
      return cloneDeep(Object.assign({}, clone(nullValue.value), parentDefaultValue))
    }
    
    if (default_.value === undefined) {
      return clone(nullValue.value)
    }
    
    let def = clone(default_.value)
    
    if (!isPlainObject(def)) {
      let tempDefault = {}
      
      each(nullValue.value, (v, language) => {
        tempDefault[language] = def
      })
      
      def = tempDefault
    }
    
    return Object.assign({}, clone(nullValue.value), def)
  })
  
  return {
    defaultValue,
  }
}

export {
  object,
  group,
  multilingual,
  text,
}

export default base
